@@ -397,9 +397,20 @@ QPixmap StatusNotifierItemSource::KDbusImageStructToPixmap(const KDbusImageStruc
             ++uintBuf;
         }
     }
-    QImage iconImage(image.width, image.height, QImage::Format_ARGB32 );
-    memcpy(iconImage.bits(), (uchar*)image.data.data(), iconImage.byteCount());
+    if (image.width == 0 || image.height == 0) {
+        return QPixmap();
+    }
 
+    //avoid a deep copy of the image data
+    //we need to keep a reference to the image.data alive for the lifespan of the image, even if the image is copied
+    //we create a new QByteArray with a shallow copy of the original data on the heap, then delete this in the QImage cleanup
+    auto dataRef = new QByteArray(image.data);
+
+    QImage iconImage(reinterpret_cast<const uchar*>(dataRef->data()), image.width, image.height, QImage::Format_ARGB32,
+            [](void* ptr) {
+                delete static_cast<QByteArray*>(ptr);
+            },
+            dataRef);
     return QPixmap::fromImage(iconImage);
 }
 
@@ -465,10 +476,23 @@ void StatusNotifierItemSource::overlayIcon(QIcon *icon, QIcon *overlay)
 void StatusNotifierItemSource::activate(int x, int y)
 {
     if (m_statusNotifierItemInterface && m_statusNotifierItemInterface->isValid()) {
-        m_statusNotifierItemInterface->call(QDBus::NoBlock, QStringLiteral("Activate"), x, y);
+        QDBusMessage message = QDBusMessage::createMethodCall(m_statusNotifierItemInterface->service(),
+                                                              m_statusNotifierItemInterface->path(), m_statusNotifierItemInterface->interface(), QStringLiteral("Activate"));
+
+        message << x << y;
+        QDBusPendingCall call = m_statusNotifierItemInterface->connection().asyncCall(message);
+        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+        connect(watcher, &QDBusPendingCallWatcher::finished, this, &StatusNotifierItemSource::activateCallback);
     }
 }
 
+void StatusNotifierItemSource::activateCallback(QDBusPendingCallWatcher *call)
+{
+    QDBusPendingReply<void> reply = *call;
+    emit activateResult(!reply.isError());
+    call->deleteLater();
+}
+
 void StatusNotifierItemSource::secondaryActivate(int x, int y)
 {
     if (m_statusNotifierItemInterface && m_statusNotifierItemInterface->isValid()) {
