@@ -1165,7 +1165,7 @@ void ShellCorona::reconsiderOutputs()
                 addOutput(screen);
             }
         } else if (isOutputRedundant(screen)) {
-            qDebug() << "new redundant screen" << screen;
+            qDebug() << "new redundant screen" << screen << "with primary screen" << qGuiApp->primaryScreen();
 
             if (DesktopView* v = desktopForScreen(screen))
                 removeDesktop(v);
@@ -1202,7 +1202,6 @@ void ShellCorona::addOutput(QScreen* screen)
 
     DesktopView *view = new DesktopView(this, screen);
     connect(view, &QQuickWindow::sceneGraphError, this, &ShellCorona::showOpenGLNotCompatibleWarning);
-#if PLASMA_VERSION >= QT_VERSION_CHECK(5, 31, 0)
     connect(screen, &QScreen::geometryChanged, this, [=]() {
         const int id = m_screenPool->id(screen->name());
         if (id >= 0) {
@@ -1211,7 +1210,7 @@ void ShellCorona::addOutput(QScreen* screen)
             emit availableScreenRectChanged();
         }
     });
-#endif
+
     Plasma::Containment *containment = createContainmentForActivity(m_activityController->currentActivity(), insertPosition);
     Q_ASSERT(containment);
 
@@ -1887,9 +1886,9 @@ int ShellCorona::screenForContainment(const Plasma::Containment *containment) co
     }
 
     //if the desktop views already exist, base the decision upon them
-    foreach (int id, m_desktopViewforId.keys()) {
-        if (m_desktopViewforId.value(id)->containment() == containment && containment->activity() == m_activityController->currentActivity()) {
-            return id;
+    for (auto it = m_desktopViewforId.constBegin(), end = m_desktopViewforId.constEnd(); it != end; ++it) {
+        if (it.value()->containment() == containment && containment->activity() == m_activityController->currentActivity()) {
+            return it.key();
         }
     }
 
